Processor.App.Downloader.downloader.DownloaderFull.\_\_init\_\_
===============================================================

.. currentmodule:: Processor.App.Downloader.downloader

.. automethod:: DownloaderFull.__init__